Enum MoveAuthenticator
#[non_exhaustive]pub enum MoveAuthenticator {
V1(MoveAuthenticatorV1),
}Expand description
MoveAuthenticator is a signature variant that enables a method of authentication through Move code. This type represents the data received by the Move authenticate function during the Account Abstraction authentication flow.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Implementations
impl MoveAuthenticator
impl MoveAuthenticator
pub fn digest(&self) -> Digest
impl MoveAuthenticator
impl MoveAuthenticator
pub fn as_v1(&self) -> &MoveAuthenticatorV1
pub fn as_v1(&self) -> &MoveAuthenticatorV1
Converts this into a v1 if it is a v1 variant, or panics otherwise.
pub fn as_mut_v1(&mut self) -> &mut MoveAuthenticatorV1
pub fn as_mut_v1(&mut self) -> &mut MoveAuthenticatorV1
Converts this into a mut v1 if it is a v1 variant, or panics otherwise.
pub fn as_opt_v1(&self) -> Option<&MoveAuthenticatorV1>
pub fn as_opt_v1(&self) -> Option<&MoveAuthenticatorV1>
Converts this into a v1 if it is a v1 variant, or returns None otherwise.
pub fn as_opt_mut_v1(&mut self) -> Option<&mut MoveAuthenticatorV1>
pub fn as_opt_mut_v1(&mut self) -> Option<&mut MoveAuthenticatorV1>
Converts this into a mut v1 if it is a v1 variant, or returns None otherwise.
pub fn into_opt_v1(self) -> Option<MoveAuthenticatorV1>
pub fn into_opt_v1(self) -> Option<MoveAuthenticatorV1>
Converts this into a v1 if it is a v1 variant, or returns None otherwise.
pub fn into_v1(self) -> MoveAuthenticatorV1
pub fn into_v1(self) -> MoveAuthenticatorV1
Converts this into a v1 if it is a v1 variant, or panics otherwise.
pub fn address(&self) -> Address
pub fn address(&self) -> Address
Returns the address of the object being authenticated, which acts as the sender of the transaction.
impl MoveAuthenticator
impl MoveAuthenticator
pub fn from_bytes( bytes: impl AsRef<[u8]>, ) -> Result<MoveAuthenticator, SignatureFromBytesError>
pub fn to_bytes(&self) -> Vec<u8> ⓘ