pub fn make_transaction(
sender: Address,
kp: &SimpleKeypair,
) -> TransactionEnvelopeExpand description
Make a user signed transaction with the given sender and its keypair. This is not verified or signed by authority.
pub fn make_transaction(
sender: Address,
kp: &SimpleKeypair,
) -> TransactionEnvelopeMake a user signed transaction with the given sender and its keypair. This is not verified or signed by authority.